@@ -20,9 +20,11 @@
 
 /* This is a minimal SMTP server with GNU SASL authentication support.
 
-   The only valid password is "sesam".  This server will complete
-   authentications using LOGIN, PLAIN, DIGEST-MD5, CRAM-MD5,
-   SCRAM-SHA-1 and SCRAM-SHA-256.
+   This server will complete authentications using LOGIN, PLAIN,
+   DIGEST-MD5, CRAM-MD5, SCRAM-SHA-1, SCRAM-SHA-256, GSSAPI and GS2.
+
+   The only valid password is "sesam".  For GSSAPI/GS2, the hostname
+   is hard coded as "smtp.gsasl.example" and the service type "smtp".
 
    It accepts an optional command line parameter specifying the
    service name (i.e., a numerical port number or /etc/services name).
@@ -50,22 +52,40 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
       rc = gsasl_property_set (sctx, prop, "sesam");
       break;
 
+      /* These are for GSSAPI/GS2 only. */
+    case GSASL_SERVICE:
+      rc = gsasl_property_set (sctx, prop, "smtp");
+      break;
+    case GSASL_HOSTNAME:
+      rc = gsasl_property_set (sctx, prop, "smtp.gsasl.example");
+      break;
+    case GSASL_VALIDATE_GSSAPI:
+      return GSASL_OK;
+
     default:
       /* You may want to log (at debug verbosity level) that an
          unknown property was requested here, possibly after filtering
          known rejected property requests. */
+      printf ("unknown gsasl callback %u\n", prop);
       break;
     }
 
   return rc;
 }
 
+#define print(fh, ...)							\
+  printf ("S: "), printf (__VA_ARGS__), fprintf (fh, __VA_ARGS__)
+
 static ssize_t
 gettrimline (char **line, size_t *n, FILE * fh)
 {
   ssize_t s = getline (line, n, fh);
 
-  if (s >= 2)
+  if (s < 0 && feof (fh))
+    print (fh, "221 localhost EOF\n");
+  else if (s < 0)
+    print (fh, "221 localhost getline failure: %s\n", strerror (errno));
+  else if (s >= 2)
     {
       if ((*line)[strlen (*line) - 1] == '\n')
 	(*line)[strlen (*line) - 1] = '\0';
@@ -78,9 +98,6 @@ gettrimline (char **line, size_t *n, FILE * fh)
   return s;
 }
 
-#define print(fh, ...)							\
-  printf ("S: "), printf (__VA_ARGS__), fprintf (fh, __VA_ARGS__)
-
 static void
 server_auth (FILE * fh, Gsasl_session * session, char *initial_challenge)
 {
@@ -107,10 +124,7 @@ server_auth (FILE * fh, Gsasl_session * session, char *initial_challenge)
 	  gsasl_free (p);
 
 	  if (gettrimline (&line, &n, fh) < 0)
-	    {
-	      print (fh, "221 localhost getline failure\n");
-	      goto done;
-	    }
+	    goto done;
 	}
     }
   while (rc == GSASL_NEEDS_MORE);
@@ -124,8 +138,11 @@ server_auth (FILE * fh, Gsasl_session * session, char *initial_challenge)
   {
     const char *authid = gsasl_property_fast (session, GSASL_AUTHID);
     const char *authzid = gsasl_property_fast (session, GSASL_AUTHZID);
-    print (fh, "235 OK [authid: %s authzid: %s]\n",
-	   authid ? authid : "N/A", authzid ? authzid : "N/A");
+    const char *gssname =
+      gsasl_property_fast (session, GSASL_GSSAPI_DISPLAY_NAME);
+    print (fh, "235 OK [authid: %s authzid: %s gssname: %s]\n",
+	   authid ? authid : "N/A", authzid ? authzid : "N/A",
+	   gssname ? gssname : "N/A");
   }
 
 done:
@@ -202,9 +219,6 @@ smtp (FILE * fh, Gsasl * ctx)
 	print (fh, "500 unrecognized command\n");
     }
 
-  if (errno)
-    print (fh, "221 localhost getline failure: %s\n", strerror (errno));
-
   free (line);
 }
 
