@@ -33,14 +33,7 @@
 /* Get specification. */
 #include "x-gssapi.h"
 
-#ifdef HAVE_LIBGSS
-# include <gss.h>
-#elif HAVE_GSSAPI_H
-# include <gssapi.h>
-#elif HAVE_GSSAPI_GSSAPI_H
-# include <gssapi/gssapi.h>
-#endif
-
+/* For GSS-API prototypes. */
 #include "gss-extra.h"
 
 struct _Gsasl_gssapi_client_state
@@ -206,10 +199,6 @@ _gsasl_gssapi_client_step (Gsasl_session * sctx,
       /* FIXME: Fix maxbuf. */
 
       p = gsasl_property_get (sctx, GSASL_AUTHZID);
-      if (!p)
-	/* The following is for backwards compatibility: this
-	   mechanism only used GSASL_AUTHID before. */
-	p = gsasl_property_get (sctx, GSASL_AUTHID);
       if (!p)
 	p = "";
 
